# encoding: utf-8
module Git
  class Runner
    private

    attr_reader :command, :stdout

    public

    def initialize(command)
      @command = command
    end

    def run
      stdout, stderr, status = Open3.capture3(command)
      fail RuntimeError, "Error executing command #{command}: #{stderr}" unless status.success?

      @stdout = stdout.split("\n")
    rescue Errno::ENOENT => e
      fail RuntimeError, "Error executing command #{command}: #{e.message}"
    end

    def result
      $stderr.puts command if Git.debug_mode
      run
      stdout
    end
  end
end
